ModbusByteTransport class abstract

Implementers

Constructors

ModbusByteTransport()

Properties

hashCode int
The hash code for this object.
no setterinherited
incoming Stream<Uint8List>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() Future<void>
send(List<int> bytes) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited