menu
mcp_io_modbus package
documentation
mcp_io_modbus.dart
ModbusByteTransport class
ModbusByteTransport class
dark_mode
light_mode
ModbusByteTransport
class
abstract
Implementers
InMemoryModbusByteTransport
TcpModbusByteTransport
Constructors
ModbusByteTransport
()
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
incoming
→
Stream
<
Uint8List
>
no setter
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
close
(
)
→
Future
<
void
>
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open
(
)
→
Future
<
void
>
send
(
List
<
int
>
bytes
)
→
Future
<
void
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
mcp_io_modbus package
documentation
mcp_io_modbus
ModbusByteTransport class
mcp_io_modbus library